| Title: | Open Working Directory |
|---|---|
| Description: | Open the current working directory (or a given directory path) in your computer's file manager. |
| Authors: | Benjamin G. Feakins [aut, cre] (ORCID: <https://orcid.org/0000-0002-3928-6750>), Benjamin J. Cairns [ctb] (ORCID: <https://orcid.org/0000-0001-7994-8213>), University of Oxford [cph, sht] |
| Maintainer: | Benjamin G. Feakins <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0-7 |
| Built: | 2026-05-21 10:45:29 UTC |
| Source: | https://github.com/feakster/owd |
owd opens the current working directory (or a given directory path) in your computer's file manager.
owd(dir = '.')owd(dir = '.')
dir |
A character string indicating a directory path. Defaults to |
owd does not return any value in R. However, it will return an error if a directory path is passed to it that does not exist, or that R does not have sufficient privledges to access.
Tilde expansion (see path.expand) is performed on directory paths.
Benjamin G. Feakins, [email protected]
getwd for the path of the current working directory.
list.files for the contents of a directory.
if (interactive()) { ## Open current working directory owd() ## Open a directory using a relative path owd('/usr/bin') ## Making use of tilde expansion to open the home directory owd('~') }if (interactive()) { ## Open current working directory owd() ## Open a directory using a relative path owd('/usr/bin') ## Making use of tilde expansion to open the home directory owd('~') }